from distutils.core import Extension
from distutils.errors import CCompilerError, DistutilsExecError, DistutilsPlatformError
from distutils.command.build_ext import build_ext

ext_modules = [
    Extension("_case", sources=["yascc/case.c"], extra_compile_args=['-Wno-xxxx']),
]


class BuildFailed(Exception):
    pass


class ExtBuilder(build_ext):
    def run(self):
        try:
            build_ext.run(self)
        except (DistutilsPlatformError, FileNotFoundError):
            print("Could not compile C extension.")

    def build_extension(self, ext):
        try:
            build_ext.build_extension(self, ext)
        except (CCompilerError, DistutilsExecError, DistutilsPlatformError, ValueError):
            print("Could not compile C extension.")


def build(setup_kwargs):
    """
    This function is mandatory in order to build the extensions.
    """
    setup_kwargs.update(
        {"ext_modules": ext_modules, "cmdclass": {"build_ext": ExtBuilder}}
    )



from __future__ import annotations

from typing import Any, Union
from .common import apply

from _case import _to_snake_case


def to_snake_case(src: str) -> str:
    return str(_to_snake_case(src))


def decamelize(d: Union[dict[str, Any], list[Any]]) -> Union[dict[str, Any], list[Any]]:
    return apply(to_snake_case, d)


if __name__ == "__main__":
    import sys

    from _bench import _bench

    _bench(sys.modules[__name__])



import inspect
import timeit
from functools import partial

import yascc


def _bench(module, test_string="thisIsVeryEasyString", number=5_000_000):
    getter = partial(getattr, module)
    for attr in dir(module):
        if not attr.startswith("to_"):
            continue
        func = getter(attr)
        if not callable(func):
            continue
        setup = f"from {module.__name__} import {attr}"
        print("*" * 80)
        print(f'version: {yascc.__version__}')
        print(f"testing {attr} func:")
        print(setup)
        print(inspect.getsource(func))
        print(f'Sample output for "{test_string}" is {func(test_string)}')
        print(f"Runs: {number}")
        time = timeit.timeit(f'{attr}("{test_string}")'.strip(), setup=setup, number=number)
        print(f"Time: {time}")



from __future__ import annotations

from typing import Any

from _case import _to_camel_case

from .common import apply


def to_camel_case(snake_case_string: str) -> str:
    return str(_to_camel_case(snake_case_string))


def camelize(d: dict[str, Any]) -> dict[str, Any]:
    return apply(to_camel_case, d)


if __name__ == "__main__":
    import sys

    from _bench import _bench

    _bench(sys.modules[__name__], test_string="this_is_very_easy_string")



from functools import partial
from typing import Callable, Union


def apply(function: Callable[[str], str], obj: Union[dict, list]) -> Union[dict, list]:
    if not isinstance(obj, dict):
        if isinstance(obj, list):
            return [*map(partial(apply, function), obj)]
        return obj
    return {function(key): apply(function, value) for key, value in obj.items()}



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['yascc']

package_data = \
{'': ['*']}

install_requires = \
['setuptools>=60.5.0,<61.0.0']

extras_require = \
{':python_version < "3.8"': ['importlib-metadata']}

entry_points = \
{'console_scripts': ['pypi = publish']}

setup_kwargs = {
    'name': 'yascc',
    'version': '0.2.2',
    'description': 'swap cases',
    'long_description': None,
    'author': 'urm8',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}
from build import *
build(setup_kwargs)

setup(**setup_kwargs)
